Interval

Interval()

A non-decreasing interval between two plain coordinates.

Parameters

Name Type Description Default
start Inclusive interval start. required
end Exclusive interval end. required

Raises

Name Type Description
TypeError If either endpoint is not a plain :class:Coordinate.
ValueError If endpoint units or number types differ, or if the end precedes the start.

Attributes

Name Description
duration Return the exact non-negative interval duration.
number_type Return the common endpoint number type.
unit Return the common endpoint unit.